Usage
=====

Import
------

To use ``PyPitch`` in your project::

    from pypitch import pypitch


Modules
-------

There a two modules available:

- ``Analyzer``: to analyze input audio and transform it into useable data
- ``Tone``: to represent tones.
